import React, { useState } from "react";
import bibtexParse from 'bibtex-parser-js';

interface BibEntry {
  ENTRYTYPE: string;
  title?: string;
  author?: string;
  journal?: string;
  volume?: string;
  pages?: string;
  year?: string;
  doi?: string;
  [key: string]: any;
}

interface BibtexParserProps {
  bibtexSources: string[]; // Accept an array of BibTeX strings
}

export const BibtexParser: React.FC<BibtexParserProps> = ({ bibtexSources }) => {
  const [parsedEntries, setParsedEntries] = useState<BibEntry[]>([]);

  // Parse BibTeX on component mount or when sources change
  // Inside the useEffect
React.useEffect(() => {
    try {
      const allEntries: BibEntry[] = [];
      bibtexSources.forEach((bibtex) => {
        const parsed = bibtexParse.toJSON(bibtex);
        allEntries.push(...parsed);
      });
      setParsedEntries(allEntries);
    } catch (error) {
      console.error("Error parsing BibTeX: ", error);
      alert("An error occurred while parsing the BibTeX entries.");
    }
  }, [bibtexSources]);
  

  // Helper function to render authors
  const renderAuthors = (authors: string) => {
    const authorList = authors.split(" and ");
    return authorList.map((author, index) => (
      <span key={index}>
        {author}
        {index < authorList.length - 1 ? ", " : ""}
      </span>
    ));
  };

  // Helper function to render individual citations based on their type
// Helper function to render individual citations based on their type
const renderCitation = (entry: BibEntry, index: number) => {
    switch (entry.ENTRYTYPE) {
      case "article":
        return (
          <li key={index}>
            <span>{renderAuthors(entry.author || "")}</span>&nbsp;
            <span>{entry.title}</span>.&nbsp;
            <i>{entry.journal}</i>,&nbsp;
            <b>{entry.volume}</b>,&nbsp;
            <span>{entry.pages}</span> ({entry.year}).&nbsp;
            {entry.doi && (
              <a href={`https://doi.org/${entry.doi}`}>
                doi: {entry.doi}
              </a>
            )}
          </li>
        );
  
      case "book":
        return (
          <li key={index}>
            <span>{renderAuthors(entry.author || entry.editor || "")}</span>&nbsp;
            <span>{entry.title}</span>.&nbsp;
            <i>{entry.publisher}</i>,&nbsp;{entry.year}.
          </li>
        );
  
      case "misc":
        return (
          <li key={index}>
            <span>{entry.author}</span>&nbsp;
            <span>{entry.title}</span>.&nbsp;
            <i>{entry.howpublished}</i>,&nbsp;{entry.year}.
          </li>
        );
  
      // Handle additional entry types here
      case "inproceedings":
        return (
          <li key={index}>
            <span>{renderAuthors(entry.author || "")}</span>&nbsp;
            <span>{entry.title}</span>. In <i>{entry.booktitle}</i>,&nbsp;
            <b>{entry.editor}</b>, {entry.year}.
          </li>
        );
  
      case "phdthesis":
        return (
          <li key={index}>
            <span>{renderAuthors(entry.author || "")}</span>&nbsp;
            <span>{entry.title}</span>, PhD thesis, {entry.school}, {entry.year}.
          </li>
        );
  
      default:
        return <li key={index}>Unknown entry type: {entry.ENTRYTYPE}</li>;
    }
  };
  

  return (
    <div>
      <h2>Citations</h2>
      <ol>
        {parsedEntries.map((entry, index) => renderCitation(entry, index))}
      </ol>
    </div>
  );
};

export default BibtexParser;
